Author: lasgouttes
Date: Mon Mar 21 15:48:22 2011
New Revision: 37984
URL: http://www.lyx.org/trac/changeset/37984

Log:
Almost finish fixing bug http://www.lyx.org/trac/ticket/6623

Now we specify the output file for sweave explicitely for robustness reasons.
We also specify prefix.string (in order to have the temp files generated in lyx 
tmp directory.

The only annoying file now is Rplots.pdf, but I am not sure why it is 
generated...

Modified:
   lyx-devel/trunk/lib/configure.py
   lyx-devel/trunk/lib/scripts/lyxsweave.R

Modified: lyx-devel/trunk/lib/configure.py
==============================================================================
--- lyx-devel/trunk/lib/configure.py    Mon Mar 21 11:42:40 2011        (r37983)
+++ lyx-devel/trunk/lib/configure.py    Mon Mar 21 15:48:22 2011        (r37984)
@@ -627,7 +627,7 @@
         rc_entry = [r'''\converter literate   latex      "%%"  ""
 \converter literate   pdflatex      "%%"       ""'''])
     #
-    checkProg('a Sweave -> LaTeX converter', ['Rscript --no-save --no-restore 
$$s/scripts/lyxsweave.R $$p$$i $$e $$r'],
+    checkProg('a Sweave -> LaTeX converter', ['Rscript --verbose --no-save 
--no-restore $$s/scripts/lyxsweave.R $$p$$i $$p$$o $$e $$r'],
         rc_entry = [r'''\converter sweave   latex      "%%"    ""
 \converter sweave   pdflatex      "%%" ""'''])
     #

Modified: lyx-devel/trunk/lib/scripts/lyxsweave.R
==============================================================================
--- lyx-devel/trunk/lib/scripts/lyxsweave.R     Mon Mar 21 11:42:40 2011        
(r37983)
+++ lyx-devel/trunk/lib/scripts/lyxsweave.R     Mon Mar 21 15:48:22 2011        
(r37984)
@@ -1,7 +1,8 @@
 # Wrapper around Sweave that sets up some things for LyX
 # argument 1 is the file name
 # argument 2 is the iconv name for the encoding of the file
 # argument 3 is the document directory
 
 ls.args <- commandArgs(trailingOnly=T)
 
@@ -11,11 +12,15 @@
 
 # set default encoding to the one of the file; it will be reset to previous
 # default by the sweave module
-ls.enc=getOption("encoding")
-options(encoding=ls.args[2])
+ls.enc <- getOption("encoding")
+options(encoding=ls.args[3])
 
 # pass document dir to sweave module
-ls.dir <- ls.args[3]
+ls.dir <- ls.args[4]
 
-#run sweave
-Sweave(ls.args[1], stylepath=ls.sp)
+# this is used to tell where temporary files should go
+ls.pr <- sub("\\.tex$", "", ls.args[2])
+
+
+# finally run sweave
+Sweave(file=ls.args[1], output=ls.args[2], syntax="SweaveSyntaxNoweb", 
@@ -1,7 +1,8 @@
 # Wrapper around Sweave that sets up some things for LyX
-# argument 1 is the file name
-# argument 2 is the iconv name for the encoding of the file
-# argument 3 is the document directory
+# argument 1 is the absolute name of the input file
+# argument 2 is the absolute name of the output file
+# argument 3 is the iconv name for the encoding of the file
+# argument 4 is the original document directory
 
 ls.args <- commandArgs(trailingOnly=T)
stylepath=ls.sp, prefix.string=ls.pr)

Reply via email to